#!/usr/bin/env node

const fs = require('fs');
const program = require('commander');
const download = require('download-git-repo');
const inquirer = require('inquirer');
const handlebars = require('handlebars');
const ora = require('ora');
const spinner = ora('正在下载模板...');
const chalk = require('chalk');
const symbols = require('log-symbols');
const prompt = require('./lib/prompt');
program.version('1.0.0', '-v, --version')
    .command('init <name>')
    .action(name => {
        if (!fs.existsSync(name)) {
            inquirer.prompt(prompt({name})).then(answers => {
                spinner.start();
                download('github:shenjianbo/h5-template#master', name, {clone: true}, err => {
                    spinner.succeed();
                    const {
                        version,
                        description,
                        keywords,
                        author,
                        license,
                        main
                    } = answers;
                    const meta = {
                        name,
                        version,
                        description,
                        keywords,
                        author,
                        license,
                        main
                    };
                    const fileName = `${name}/package.config.json`;
                    const outputName = `${name}/package.json`;
                    if (fs.existsSync(outputName)) {
                        const content = fs.readFileSync(fileName).toString();
                        const result = handlebars.compile(content)(meta);
                        fs.writeFileSync(outputName, result);
                        fs.unlinkSync(fileName);
                    }
                    console.log(symbols.success, chalk.green('项目初始化完成'));
                });
            });
        }
        else {
            console.log(symbols.error, chalk.red('项目已存在'));
        }
    });
program.parse(process.argv);